@@ -15,14 +15,9 @@ New in pyfakefs 3.0.
 
 Usage:
 
-* With fake_filesystem_unittest:
-  If using fake_filesystem_unittest.TestCase, pathlib gets replaced
-  by fake_pathlib together with other file system related modules.
-
-* Stand-alone with FakeFilesystem:
-  `filesystem = fake_filesystem.FakeFilesystem()`
-  `fake_pathlib_module = fake_filesystem.FakePathlibModule(filesystem)`
-  `path = fake_pathlib_module.Path('/foo/bar')`
+If using `fake_filesystem_unittest.TestCase`, pytest fs fixture,
+or directly `Patcher`, pathlib gets replaced
+by fake_pathlib together with other file system related modules.
 
 Note: as the implementation is based on FakeFilesystem, all faked classes
 (including PurePosixPath, PosixPath, PureWindowsPath and WindowsPath)
@@ -42,6 +37,7 @@ import sys
 import warnings
 from pathlib import PurePath
 from typing import Callable, List, Optional
+from unittest import mock
 from urllib.parse import quote_from_bytes as urlquote_from_bytes
 
 from pyfakefs import fake_scandir
@@ -446,7 +442,7 @@ if sys.version_info < (3, 12):
         pathmod = ntpath
 
         def is_reserved(self, parts):
-            """Return True if the path is considered reserved under Windows."""
+            """Return `True` if the path is considered reserved under Windows."""
 
             # NOTE: the rules for reserved names seem somewhat complicated
             # (e.g. r"..\NUL" is reserved but not r"foo\NUL").
@@ -554,6 +550,7 @@ if sys.version_info < (3, 12):
 
         def compile_pattern(self, pattern):
             return re.compile(fnmatch.translate(pattern)).fullmatch
+
 else:  # Python >= 3.12
 
     class FakePosixPathModule(FakePathModule):
@@ -662,7 +659,7 @@ class FakePath(pathlib.Path):
             under Windows).
 
             Args:
-                strict: If False (default) no exception is raised if the path
+                strict: If `False` (default) no exception is raised if the path
                     does not exist.
 
             Raises:
@@ -831,11 +828,11 @@ class FakePath(pathlib.Path):
 
         Args:
             mode: the file mode for the file if it does not exist
-            exist_ok: if the file already exists and this is True, nothing
-                happens, otherwise FileExistError is raised
+            exist_ok: if the file already exists and this is `True`, nothing
+                happens, otherwise `FileExistError` is raised
 
         Raises:
-            FileExistsError: if the file exists and exits_ok is False.
+            FileExistsError: if the file exists and ``exits_ok`` is `False`.
         """
         self._raise_on_closed()
         if self.exists():
@@ -848,6 +845,35 @@ class FakePath(pathlib.Path):
             fake_file.close()
             self.chmod(mode)
 
+    if sys.version_info >= (3, 14):
+
+        def _copy_from_file(self, source, preserve_metadata=False):
+            if sys.platform == "win32":
+                # do not use the optimized version that uses OS functions in Windows
+                if hasattr(self, "_copy_from_file_fallback"):
+                    return self._copy_from_file_fallback(source, preserve_metadata)
+                else:
+                    return super()._copy_from_file(source, preserve_metadata)  # type: ignore[attr-defined]
+            else:
+                # make pathlib think that no system calls are available so that it
+                # will fall back to pure Python calls
+                pathlib_os = pathlib.pathlib_module._os  # type: ignore[attr-defined]
+                old_fcopyfile = pathlib_os._fcopyfile
+                pathlib_os._fcopyfile = None
+                old_copy_file_range = pathlib_os._copy_file_range  # type: ignore[attr-defined]
+                pathlib_os._copy_file_range = None
+                old_ficlone = pathlib_os._ficlone  # type: ignore[attr-defined]
+                pathlib_os._ficlone = None
+                old_sendfile = pathlib_os._sendfile  # type: ignore[attr-defined]
+                pathlib_os._sendfile = None
+                try:
+                    return super()._copy_from_file(source, preserve_metadata)  # type: ignore[attr-defined]
+                finally:
+                    pathlib_os._fcopyfile = old_fcopyfile
+                    pathlib_os._copy_file_range = old_copy_file_range
+                    pathlib_os._ficlone = old_ficlone
+                    pathlib_os._sendfile = old_sendfile
+
 
 def _warn_is_reserved_deprecated():
     if sys.version_info >= (3, 13):
@@ -862,23 +888,43 @@ def _warn_is_reserved_deprecated():
 class FakePathlibModule:
     """Uses FakeFilesystem to provide a fake pathlib module replacement.
 
-    You need a fake_filesystem to use this:
-    `filesystem = fake_filesystem.FakeFilesystem()`
-    `fake_pathlib_module = fake_filesystem.FakePathlibModule(filesystem)`
+    Automatically created if using `fake_filesystem_unittest.TestCase`,
+    the `fs` fixture, the `patchfs` decorator, or directly the `Patcher`.
     """
 
-    def __init__(self, filesystem):
+    def __init__(self, filesystem, from_patcher=False):
         """
         Initializes the module with the given filesystem.
 
         Args:
             filesystem: FakeFilesystem used to provide file system information
+            from_patcher: If `False` (the default), `pathlib.os` will be manually
+                patched using `FakeOsModule`. This allows to instantiate the class
+                manually for a test.
+                Will be set to `True` if instantiated from `Patcher`.
         """
         init_module(filesystem)
-        self._pathlib_module = pathlib
+        self.pathlib_module = pathlib
+        self._os = None
+        self._os_patcher = None
+        if not from_patcher:
+            self.patch_os_module()
+
+    def patch_os_module(self):
+        if sys.version_info >= (3, 11) and not isinstance(os, FakeOsModule):
+            self._os = FakeOsModule(FakePath.filesystem)
+            pathlib_os = (
+                "pathlib._local.os" if sys.version_info[:2] == (3, 13) else "pathlib.os"
+            )
+            self._os_patcher = mock.patch(pathlib_os, self._os)
+            self._os_patcher.start()
+
+    def __del__(self):
+        if self._os_patcher is not None:
+            self._os_patcher.stop()
 
     class PurePosixPath(PurePath):
-        """A subclass of PurePath, that represents non-Windows filesystem
+        """A subclass of PurePath that represents non-Windows filesystem
         paths"""
 
         __slots__ = ()
@@ -897,7 +943,7 @@ class FakePathlibModule:
                     return super().joinpath(*pathsegments)
 
     class PureWindowsPath(PurePath):
-        """A subclass of PurePath, that represents Windows filesystem paths"""
+        """A subclass of PurePath that represents Windows filesystem paths"""
 
         __slots__ = ()
 
@@ -981,7 +1027,7 @@ class FakePathlibModule:
 
     def __getattr__(self, name):
         """Forwards any unfaked calls to the standard pathlib module."""
-        return getattr(self._pathlib_module, name)
+        return getattr(self.pathlib_module, name)
 
 
 class FakePathlibPathModule:
@@ -989,9 +1035,9 @@ class FakePathlibPathModule:
 
     fake_pathlib = None
 
-    def __init__(self, filesystem=None):
+    def __init__(self, filesystem=None, from_patcher=False):
         if self.fake_pathlib is None:
-            self.__class__.fake_pathlib = FakePathlibModule(filesystem)
+            self.__class__.fake_pathlib = FakePathlibModule(filesystem, from_patcher)
 
     @property
     def skip_names(self):
