@@ -18,17 +18,21 @@ from pathlib import Path
 
 
 def read_pathlib(file_name):
-    return (Path(__file__).parent / file_name).open("r").read()
+    return (Path(__file__).parent / file_name).open("r", encoding="utf8").read()
 
 
 def read_text_pathlib(file_name):
-    return (Path(__file__).parent / file_name).read_text()
+    return (Path(__file__).parent / file_name).read_text(encoding="utf8")
 
 
 def read_bytes_pathlib(file_name):
     return (Path(__file__).parent / file_name).read_bytes()
 
 
+def check_exists_pathlib():
+    return os.path.exists(__file__) and Path(__file__).exists()
+
+
 def read_open(file_name):
-    with open(os.path.join(os.path.dirname(__file__), file_name)) as f:
+    with open(os.path.join(os.path.dirname(__file__), file_name), encoding="utf8") as f:
         return f.read()
